@@ -1,8 +1,8 @@
 ###############################################################################
 #DTL.pm
-#Last Change: 2008-01-19
+#Last Change: 2008-12-15
 #Copyright (c) 2006 Marc-Seabstian "Maluku" Lucksch
-#Version 0.8
+#Version 0.1
 ####################
 #This file is part of the Dotiac::DTL project. 
 #http://search.cpan.org/perldoc?Dotiac::DTL
@@ -16,8 +16,15 @@
 
 
 package Dotiac::DTL;
-use base qw/Dotiac::DTL::Core/; #This is only used to make Test::Pod::Coverage, since most functions in the Dotiac::DTL namespace are documented in that file.
 require Dotiac::DTL::Tag;
+require Dotiac::DTL::Filter;
+require Dotiac::DTL::Variable;
+require Dotiac::DTL::Comment;
+require Dotiac::DTL::Compiled;
+
+BEGIN {
+	require Dotiac::DTL::Core;
+}
 require Digest::MD5;
 use Carp qw/confess/;
 use strict;
@@ -28,7 +35,7 @@ require File::Basename;
 
 our @EXPORT=();
 our @EXPORT_OK=qw/Context Template/;
-our $VERSION = 0.8;
+our $VERSION = 0.1;
 
 
 
@@ -58,6 +65,117 @@ sub Context {
 	return $_[0];
 }
 
+sub unparsed {
+	my $self=shift;
+	my $template=shift;
+	my $pos=shift;
+	my $start=$$pos;
+	my @end = @_;
+	my $found;
+	my $starttag;
+	$found=shift @end if @end;
+	$starttag=shift @end if @end;
+	my @starttag;
+	@starttag = ($starttag) if $starttag and not ref $starttag;
+	@starttag = @{$starttag} if $starttag and ref $starttag eq "ARRAY";
+	my $text;
+	local $_;
+	while (1) {
+		my $p = index($$template,"{",$$pos);
+		if ($p >=0) {
+			$$pos=$p+1;
+			my $n = substr $$template,$$pos,1;
+			if ($n eq "%") {
+				my $text .= substr $$template,$start,$$pos-$start-1;
+				my $npos = index($$template,"%}",++$$pos);
+				die "Missing closing %} at char $$pos" if $npos < 0;
+				my $cont=substr $$template,$$pos,$npos-$$pos;
+				$$pos=$npos+2;
+				my $c=$cont;
+				$cont=~s/^\s+//;
+				$cont=~s/\s+$//;
+				my ($tagname,$param) = split /\s+/,$cont,2;
+				$tagname=lc $tagname;
+				$$found = $c and return $text if $found and grep {$_ eq $tagname} @end;
+				$text .= "{\%$c\%}";
+				$text .= $self->unparsed($template,$pos,@_) if $found and grep {$_ eq $tagname} @starttag;
+				$text .="{\%$$found\%}";
+				$$found="";				
+			}
+		}
+		else {
+			$$pos=length $$template;
+			return $text
+		}
+	}
+}
+
+
+sub parse {
+	my $self=shift;
+	my $template=shift;
+	my $pos=shift;
+	my $start=$$pos;
+	my @end = @_;
+	my $found;
+	$found=shift @end if @end;
+	local $_;
+	while (1) {
+		my $p = index($$template,"{",$$pos);
+		if ($p >=0) {
+			$$pos=$p+1;
+			my $n = substr $$template,$$pos,1;
+			if ($n eq "%") {
+				my $pre = substr $$template,$start,$$pos-$start-1;
+				my $npos = index($$template,"%}",++$$pos);
+				die "Missing closing %} at char $$pos" if $npos < 0;
+				my $cont=substr $$template,$$pos,$npos-$$pos;
+				$$pos=$npos+2;
+				$cont=~s/^\s+//;
+				$cont=~s/\s+$//;
+				my ($tagname,$param) = split /\s+/,$cont,2;
+				$tagname=lc $tagname;
+				$$found = $tagname and return Dotiac::DTL::Tag->new($pre) if $found and grep {$_ eq $tagname} @end;
+				my $r;
+				eval {$r="Dotiac::DTL::Tag::$tagname"->new($pre,$param,$self,$template,$pos);};
+				if ($@) {
+					die "Error while loading Tag '$tagname' from Dotiac::DTL::Tag::$tagname. If this is an endtag (like endif) then your template is unbalanced\n$@";
+				}
+				#print "\n\nold: $npos, new $$pos, lenght=".length $$template and die if $tagname eq "extends";
+				#warn $$pos," ",length $$template,"\n";
+				if ($$pos >= length $$template) {
+					$r->next(Dotiac::DTL::Tag->new(""));
+				}
+				else {
+					$r->next($self->parse($template,$pos,@_));
+				}
+				return $r;
+				
+			}
+			elsif ($n eq "{") {
+				my $pre = substr $$template,$start,$$pos-$start-1;
+				my $npos = index($$template,"}}",++$$pos);
+				die "Missing closing }} at char $$pos" if $npos < 0;
+				my $cont=substr $$template,$$pos,$npos-$$pos;
+				$$pos=$npos+2;
+				return Dotiac::DTL::Variable->new($pre,$cont,$self->parse($template,$pos,@_));
+			}
+			elsif ($n eq "#") {
+				my $pre = substr $$template,$start,$$pos-$start-1;
+				my $npos = index($$template,"#}",++$$pos);
+				die "Missing closing #} at char $$pos" if $npos < 0;
+				my $cont=substr $$template,$$pos,$npos-$$pos;
+				$$pos=$npos+2;
+				return Dotiac::DTL::Comment->new($pre,$cont,$self->parse($template,$pos,@_));
+			}
+		}
+		else {
+			$$pos=length $$template;
+			return Dotiac::DTL::Tag->new(substr $$template,$start);
+		}
+	}
+}
+
 my %cache;
 sub newandcompile {
 	my $class=shift;
@@ -67,36 +185,26 @@ sub newandcompile {
 {
 	no warnings "redefine";
 	sub new {
-		%Dotiac::DTL::params=();
 		my $class=shift;
 		my $data=shift; 
 		my $t="";
 		my $filename="from cache";
-		my $changetime=0;
 		my $compile=shift; #1 compile, 0 no recompile, -1 skip compiled even if its there, undef=use compiled if there, recompile if needed.
 		if (ref $data eq "SCALAR") {
 			$t=$$data;
 			$compile=0;
 			$filename="form SCALARref";
-			$Dotiac::DTL::currentdir=$Dotiac::DTL::CURRENTDIR;
+			$Dotiac::DTL::currentdir="";
 		}
 		elsif (not ref $data) {
 			$t=$data;
 			my @f = File::Basename::fileparse($data);
 			$Dotiac::DTL::currentdir=$f[1];
-			#warn "Cached:",Data::Dumper->Dump([\%cache]);
 			if (-e "$data.pm" and (($compile and $compile > 0) or not defined $compile)) {
 				if (-e $data) {
-					if ((stat("$data.pm"))[9] > (stat("$data"))[9]) {
-						
+					if (-M "$data.pm" < -M $data) {
 						eval {
-							$cache{"$data.pm"}={
-								template=>Dotiac::DTL::Compiled->new("Dotiac::DTL::Compiled::".require "$data.pm"),
-								currentdir=>$Dotiac::DTL::currentdir,
-								params=>{%Dotiac::DTL::params},
-								parser=>$Dotiac::DTL::PARSER,
-								changetime=>(stat("$data.pm"))[9]
-							} if not $cache{"$data.pm"};# or (exists $cache{"$data.pm"}->{changetime} and $cache{"$data.pm"}->{changetime} > -M "$data.pm");
+							$cache{"$data.pm"}=Dotiac::DTL::Compiled->new("Dotiac::DTL::Compiled::".require "$data.pm") unless ($cache{"$data.pm"});
 							$t="$data.pm";
 							$compile=0;
 							1;
@@ -107,24 +215,12 @@ sub newandcompile {
 					}
 					else {
 						delete $cache{"$data.pm"};
-						delete $INC{"$data.pm"}; #Otherwise it won't work.
 						$compile=1 if $compile or not defined $compile;
 					}
 				}
 				else { # $data is not more here, but $data.pm is, use that one than.
-					if ($cache{"$data.pm"} and exists $cache{"$data.pm"}->{changetime} and $cache{"$data.pm"}->{changetime} < (stat("$data.pm"))[9]) {
-						carp "Foo";
-						delete $cache{"$data.pm"};
-						delete $INC{"$data.pm"};
-					}
 					eval {
-						$cache{"$data.pm"}={
-							template=>Dotiac::DTL->compiled("Dotiac::DTL::Compiled::".require "$data.pm"),
-							currentdir=>$Dotiac::DTL::currentdir,
-							params=>{%Dotiac::DTL::params},
-							parser=>$Dotiac::DTL::PARSER,
-							changetime=>(stat("$data.pm"))[9]
-						} if not $cache{"$data.pm"};# or (exists $cache{"$data.pm"}->{changetime} and $cache{"$data.pm"}->{changetime} > -M "$data.pm");
+						$cache{"$data.pm"}=Dotiac::DTL::Compiled->new("Dotiac::DTL::Compiled::".require "$data.pm") unless ($cache{"$data.pm"});
 						$t="$data.pm";
 						$compile=0;
 						1;
@@ -134,45 +230,35 @@ sub newandcompile {
 					};	
 				}
 			}
-			if ($cache{$t} and $t eq $data and exists $cache{$t}->{changetime} and $cache{$t}->{changetime} < (stat("$t"))[9]) {
-				delete $cache{$t};
-			}
 			unless ($cache{$t})  {	
 				open my $fh,"<",$data or croak "Can't open template $data: $!";
 				binmode $fh;
 				my $a=do {local $/,<$fh>};
 				close $fh;
 				$filename="\"$data\"";
-				$changetime=(stat("$data"))[9];
 				$data=\$a;
 			}
 		}
 		else {
 			die "Can't work with $data!";
 		}
-		unless ($cache{$t}) {
-			eval "require $Dotiac::DTL::PARSER;" or croak "Can't load Parser '$Dotiac::DTL::PARSER': $@";
-			my $parser=$Dotiac::DTL::PARSER->new();
-			$cache{$t}={
-				template=>Dotiac::DTL::Tag->new("include/extend cycle detected"), #This prevents cycled includes to screw around during parsing time.
-				currentdir=>$Dotiac::DTL::currentdir,
-				params=>{%Dotiac::DTL::params},
-				parser=>$Dotiac::DTL::PARSER
-			};
+		my $self={};
+		#$self->{data}=$data;
+		bless $self,$class;
+		if ($cache{$t}) {
+			$self->{first}=$cache{$t};
+		}
+		else {
+			$cache{$t}=Dotiac::DTL::Tag->new("include/extend cycle detected"); #This prevents cycled includes to screw around during parsing time.
 			my $pos=0;
 			eval {
-				$cache{$t}={
-					template=>$parser->parse($data,\$pos),
-					currentdir=>$Dotiac::DTL::currentdir,
-					params=>{%Dotiac::DTL::params},
-					parser=>$Dotiac::DTL::PARSER,
-					changetime=>$changetime
-				};
+				$self->{first}=$self->parse($data,\$pos);
 				1;
 			} or do {
 				croak "Error while getting template $filename:\n $@\n.";
 				undef $@;
 			};
+			$cache{$t}=$self->{first};
 		}
 		if ($compile and $compile > 0) {
 			if (open my $cp,">","$t.pm") {
@@ -180,23 +266,20 @@ sub newandcompile {
 					require Data::Dumper;
 					$Data::Dumper::Indent=2;
 					$Data::Dumper::Useqq=1;
-					my $template=$cache{$t}->{template};
 					my $digest=Digest::MD5::md5_hex($t);
 					print $cp "#Autogenerated\n";
-					print $cp "package Dotiac::DTL::Compiled::$digest;\nuse strict;\nuse warnings;\nrequire Scalar::Util;\n#PARAMS USED:\nour "; 
-
-					print $cp (Data::Dumper->Dump([$cache{$t}->{params}],["\$params"]));
-					$template->perl($cp,0,$digest);
+					print $cp "package Dotiac::DTL::Compiled::$digest;\nuse strict;\nuse warnings;\nrequire Scalar::Util;\n"; 
+					$cache{$t}->perl($cp,0,$digest);
 					print $cp "\n#INIT\n";
-					$template->perlinit($cp,0,$digest);
+					$cache{$t}->perlinit($cp,0,$digest);
 					print $cp "\nsub string {\n	my \$vars=shift;\n	my \$escape=shift;\n	my \$r=\"\";\n";
-					$template->perlstring($cp,0,1,$digest);
+					$cache{$t}->perlstring($cp,0,1,$digest);
 					print $cp "	return \$r;\n}\n";
 					print $cp "sub print {\n	my \$vars=shift;\n	my \$escape=shift;\n";
-					$template->perlprint($cp,0,1,$digest);
+					$cache{$t}->perlprint($cp,0,1,$digest);
 					print $cp "}\n";
 					print $cp "sub eval {\n	my \$vars=shift;\n	my \$escape=shift;\n";
-					$template->perleval($cp,0,1,$digest);
+					$cache{$t}->perleval($cp,0,1,$digest);
 					print $cp "}\n";
 					print $cp qq("$digest";);
 					close $cp;
@@ -210,8 +293,8 @@ sub newandcompile {
 				carp "Can't open output to $$data.pm while compiling: $!";
 			}
 		}
-		Dotiac::DTL::Addon::restore();
-		return "Dotiac::DTL::Template"->new($cache{$t}->{template},$cache{$t}->{currentdir},$cache{$t}->{parser},$cache{$t}->{params});
+		$self->{vars}={};
+		return $self; #TODO Cache
 	}
 }
 1;
@@ -290,7 +373,7 @@ See new(FILE, COMPILE)
 
 =back
 
-Returns a L<Dotiac::DTL::Template> object.
+Returns a Dotiac::DTL object.
 
 =head3 Context(HASHREF)
 
@@ -306,7 +389,7 @@ A Hash of parameters.
 
 Returns the first Argument.
 
-=head2 Class constructers
+=head2 Methods
 
 =head3 new(FILENAME, COMPILE)
 
@@ -368,20 +451,12 @@ If you want to use only compiled templates, see L<Dotiac::DTL::Reduced>, which s
 
 =back
 
-Returns a L<Dotiac::DTL::Template> object.
-
-=head3 newandcompile(FILENAME)
-
-Same as new (FILENAME,1), which means: Compiles the template if it is not already compiled and recompiles if the compiled one is older.
-
-Returns a L<Dotiac::DTL::Template> object.
+Returns a Dotiac::DTL object.
 
 =cut
 
 =head2 Methods
 
-I<These work only on the returned Dotiac::DTL::Template object of new()>
-
 =head3 param(NAME, VALUE)
 
 Works like HTML::Templates param() method, will set a param that will be used for output generation.
@@ -474,8 +549,6 @@ Returns a Dotiac::DTL object
 	# This will now include and print the above package a hundert times and 
 	# will be a lot faster, depending on the contents of that for loop.
 
-=head1 DTL INTRO
-
 =head2 Comments
 
 Everything in {# and #} will be ignored by the parser. There is also a comment-tag.
@@ -590,7 +663,7 @@ There are some differences with the original template implementation of Django:
 
 I wrote this using just the documentation, so it will differ a lot on undokumented features, If you are missing something or notice something not listed here, drop me a mail.
 
-One mayor difference is: Python has a default string representation for objects (__str__()), Perl doesn't. So if you writing an object into the template it will appear as a perl pointer. For a solution to this see above.
+One mayor difference is: Python has a default string representation for objects (__str__()), Perl doesn't. So if you writing an object into the template it will appear as a perl pointer. This will change as soon as I get a nice idea how to solve this.
 
 The perl side interface is quite different from the Python one:
 	
@@ -604,14 +677,14 @@ This was to un-Perl for me, so this follows the HTML::Template way:
 
 	require Dotiac::DTL;
 	my $text="My name is {{ my_name }}.";
-	my $t=Dotiac::DTL->new("file.html");
+	my $t=Dotiac::DTL::new("file.html");
 	#or
-	my $t=Dotiac::DTL->new(\$text);
+	my $t=Dotiac::DTL::new(\$text);
 	$t->string({my_name=>"Adrian"});
 	#or 
 	$t->print({my_name=>"Adrian"});
 	
-There is also a Django-like interface.
+There is also a Django-like interface, but the one above is more clear.
 
 	use Dotiac::DTL qw/Template Context/;
 	my $t = Template("file"); #This also looks in @Dotiac::DTL::TEMPLATE_DIRS for file, file.html and file.txt if nothing exists, it treats file as a string.
@@ -623,22 +696,10 @@ There is also a Django-like interface.
 
 =head3 Tag: load
 
-The tag {% load %} will work, but do something else internally.
+The tag {% load %} will work the some, but do something else.
 
 Look at L<Dotiac::DTL::Addon> and  L<Dotiac::DTL::Tag::load> for information.
 
-The greatest difference is: 
-
-In Django the load doesn't affect included templates, in Dotiac::DTL load is global, this means you can do this:
-
-load.html:
-
-	{% load lib1 lib2 lib3 someohterlibrary %}
-
-template.html:
-
-	{% include "load.html" %} {{ text|lib1filter }}
-
 =head3 Adding filters and Tags
 
 If you want create addons with filters and tags, look at L<Dotiac::DTL::Addon>, but if you just want to add filters and Tags for one skript, this can be done easily: 
@@ -663,9 +724,7 @@ B<All parameters to filters are> L<Dotiac::DTL::Value>B<-objects and the filter
 
 =head3 Tag: url
 
-This one can't work without a complete django backend. If you have such a backend you will have to overwrite the Dotiac::DTL::Tag::url module.
-
-However, it tries to do the right thing.
+This one can't work without a complete django backend. If you have such a backendm you will have to overwrite the Dotiac::DTL::Tag::url module.
 
 =head3 Parsing
 
@@ -682,18 +741,9 @@ Some tags will also die() if the syntax is wrong.
 The normal Django templates only support a method that converts them into a long string. I added a print() method which prints directly to the current output handle. 
 This should be easier on the memory and might even a bit faster.
 
-=head3 More filter arguments
+=head3 Tag: ifchanged
 
-I thought it might be useful to allow filters to have multiple arguments, this is only useful for your own filters and some of the inofficial extension in this module. Arguments can be seperated by either a comma "," or a semicolon ";" (In some tags commas are used to split arguments, its better to always use ";")
-
-	{{ "Hello"|center:"20","-" }}
-	{% for x in  "Hello"|center:"20";"-"|make_list %}
-
-
-
-=head3 Other changes:
-
-There are some additional features to some tags and filters ( {% else %} in {% ifchanged %}, padding chars in |center |left and |right )
+Also supports {% else %} if nothing has changed. I thought it might be useful.
 
 =head2 Speed
 
@@ -777,14 +827,6 @@ L<http://sourceforge.net/tracker/?group_id=249411&atid=1126348>
 
 I did not include "django.contrib.humanize", "django.contrib.markup" and "django.contrib.webdesign" in the Core distribution, since they require some other modules (especially markup). I will release them as Addons in CPAN.
 
-=head1 LICENSE
-
-This module is published under the terms of the MIT license, which basically 
-means "Do with it whatever you want". For more information, see the 
-LICENSE file that should be enclosed with this distributions. A copy of
-the license is (at the time of writing) also available at
-L<http://www.opensource.org/licenses/mit-license.php>.
-
 =head1 LEGAL
 
 Dotiac::DTL was built according to the documentation on L<http://docs.djangoproject.com/en/dev/ref/templates/builtins/>.
