@@ -1,8 +1,8 @@
 ###############################################################################
 #Comment.pm
-#Last Change: 2009-01-19
-#Copyright (c) 2009 Marc-Seabstian "Maluku" Lucksch
-#Version 0.8
+#Last Change: 2008-12-15
+#Copyright (c) 2006 Marc-Seabstian "Maluku" Lucksch
+#Version 0.1
 ####################
 #This file is part of the Dotiac::DTL project. 
 #http://search.cpan.org/perldoc?Dotiac::DTL
@@ -18,7 +18,6 @@
 package Dotiac::DTL::Compiled;
 use strict;
 use warnings;
-our $VERSION = 0.8;
 
 sub new {
 	my $class=shift;
@@ -26,12 +25,6 @@ sub new {
 	my $self={};
 	$self->{name}=$name;
 	bless $self,$class;
-	eval {
-		#{
-		no strict 'refs';
-		#warn  Data::Dumper->Dump([${"$name"."::params"}]) if ${"$name"."::params"} and %{${"$name"."::params"}};
-		%Dotiac::DTL::params=%{${"$name"."::params"}} if ${"$name"."::params"};
-	};
 	return $self;
 }
 
@@ -55,6 +48,15 @@ sub string {
 sub perl {
 	die "Can't perlify a compiled template";
 }
+sub perlprint {
+	return "";
+}
+sub perlstring {
+	return "";
+}
+sub perleval {
+	return "";
+}
 sub eval {
 	my $self=shift;
 	my $name=$self->{name};
@@ -68,7 +70,7 @@ __END__
 
 =head1 NAME
 
-Dotiac::DTL::Compiled - Stores a compiled Django template.
+Dotiac::DTL::Compield - Stores a compiled Django template.
 
 =head1 SYNOPSIS
 
@@ -115,7 +117,7 @@ but more difficult to write.
 
 =head2 Pros and cons
 
-=head3 Pros
+B<Pros>
 
 =over
 
@@ -139,7 +141,7 @@ but more difficult to write.
 
 =back
 
-=head3 Cons
+B<Pros>
 
 =over
 
@@ -151,8 +153,6 @@ but more difficult to write.
 
 =item There is now way back from autocompiled templates to normal ones. If you loose the source, it's gone.
 
-=back
-
 =head2 Removing cons
 
 Some issues can be removed by compiling all the templates once and then just run the webserver with tight security, i.e. no write access.
