@@ -1,7 +1,7 @@
 #for.pm
-#Last Change: 2009-01-19
-#Copyright (c) 2009 Marc-Seabstian "Maluku" Lucksch
-#Version 0.8
+#Last Change: 2008-12-19
+#Copyright (c) 2006 Marc-Seabstian "Maluku" Lucksch
+#Version 0.1
 ####################
 #This file is part of the Dotiac::DTL project. 
 #http://search.cpan.org/perldoc?Dotiac::DTL
@@ -19,8 +19,6 @@ use strict;
 use warnings;
 require Scalar::Util;
 
-our $VERSION = 0.8;
-
 sub new {
 	my $class=shift;
 	my $self={p=>shift()};
@@ -174,17 +172,17 @@ sub perl {
 	my $id=shift;
 	$self->SUPER::perl($fh,$id,@_);
 	print $fh "my ";
-	print $fh (Data::Dumper->Dump([$self->{var}->[0]],["\$var$id"]));
+	print $fh Data::Dumper->Dump([$self->{var}->[0]],["\$var$id"]);
 	print $fh "my ";
-	print $fh (Data::Dumper->Dump([$self->{source}],["\$source$id"]));
+	print $fh Data::Dumper->Dump([$self->{source}],["\$source$id"]);
 	if (@{$self->{var}} > 1) {
 		print $fh "my ";
-		print $fh (Data::Dumper->Dump([$self->{var}],["\$vars$id"]));
+		print $fh Data::Dumper->Dump([$self->{var}],["\$vars$id"]);
+	}
+	if ($self->{empty}) {
+		print $fh "my ";
+		print $fh Data::Dumper->Dump([$self->{empty}],["\$empty$id"]);
 	}
-	#if ($self->{empty}) {
-	#	print $fh "my ";
-	#	print $fh (Data::Dumper->Dump([$self->{empty}],["\$empty$id"]));
-	#}
 	$id=$self->{content}->perl($fh,$id+1,@_);
 	$id=$self->{empty}->perl($fh,$id+1,@_) if $self->{empty};
 	return $self->{n}->perl($fh,$id+1,@_);
