@@ -1,7 +1,7 @@
 #with.pm
-#Last Change: 2009-01-19
-#Copyright (c) 2009 Marc-Seabstian "Maluku" Lucksch
-#Version 0.8
+#Last Change: 2008-12-29
+#Copyright (c) 2006 Marc-Seabstian "Maluku" Lucksch
+#Version 0.1
 ####################
 #This file is part of the Dotiac::DTL project. 
 #http://search.cpan.org/perldoc?Dotiac::DTL
@@ -17,7 +17,6 @@ package Dotiac::DTL::Tag::with;
 use base qw/Dotiac::DTL::Tag/;
 use strict;
 use warnings;
-our $VERSION = 0.8;
 
 sub new {
 	my $class=shift;
@@ -61,9 +60,9 @@ sub perl {
 	my $id=shift;
 	$self->SUPER::perl($fh,$id,@_);
 	print $fh "my ";
-	print $fh (Data::Dumper->Dump([$self->{var}],["\$var$id"]));
+	print $fh Data::Dumper->Dump([$self->{var}],["\$var$id"]);
 	print $fh "my ";
-	print $fh (Data::Dumper->Dump([$self->{as}],["\$as$id"]));
+	print $fh Data::Dumper->Dump([$self->{as}],["\$as$id"]);
 	$id = $self->{content}->perl($fh,$id+1,@_);
 	return $self->{n}->perl($fh,$id+1,@_)
 }
@@ -166,7 +165,7 @@ __END__
 
 =head1 NAME
 
-Dotiac::DTL::Tag::with - The {% with VARIABLE as NEWVARIABLENAME %} tag
+Dotiac::DTL::Tag::widthratio - The {% width VARIABLE as NEWVARIABLENAME %} tag
 
 =head1 SYNOPSIS
 
